#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'easycompile/base/esystem.rb'
# =========================================================================== #
module Easycompile

class Base

  require 'easycompile/constants/misc.rb'
  # ========================================================================= #
  # === esystem
  #
  # Run a colourized system() command here.
  #
  # This can either be through oldschool system(), or as of August 2017,
  # preferentially via IO.popen().
  # ========================================================================= #
  def esystem(i)
    e_colourize(i) # Output it here already.
    i = i.dup if i.frozen?
    i << ERROR_LINE
    @result = i # Not in use right now.
    internal_system(i) # Defined in this file here.
  end; alias _ esystem # === _

  # ========================================================================= #
  # === cparser_is_available?
  #
  # Determine whether we can use the ColourizeParser from the RBT
  # project.
  # ========================================================================= #
  def cparser_is_available?
    Object.const_defined?(:RBT) and
    RBT.const_defined?(:ColourizeParser)
  end

  # ========================================================================= #
  # === internal_system
  #
  # The key idea for this method is to handle system()-related calls
  # via IO.popen(). This gives us more control over as to what to
  # do with the given input and output.
  # ========================================================================= #
  def internal_system(i)
    cparser_is_available = cparser_is_available?
    cparser = @colourize_parser if cparser_is_available
    io_object = IO.popen(i, :err => [:child, :out]).each { |line|
      if cparser_is_available
        cparser.grab_this_line(line) # The cparser object will deal with colours.
        line = cparser.line?
      end
      e line # Output here.
    }
    io_object.close # Close it here.
  end

end; end