#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'easycompile/base/menu.rb'
# =========================================================================== #
module Easycompile

class Base

  # ========================================================================= #
  # === menu
  # ========================================================================= #
  def menu(
      i = commandline_arguments?
    )
    if i.is_a? Array
      i.each {|entry| menu(entry) }
    else
      case i
      # ===================================================================== #
      # === ecompile --home_dir
      # ===================================================================== #
      when /^-?-?home(_|-)?dir$/,
           /^-?-?home(_|-)?directory$/,
           /^-?-?home$/
        set_prefix(:home_directory)
      # ===================================================================== #
      # === ecompile --help
      #
      # This option allows us to show the available help options, on
      # the commandline.
      # ===================================================================== #
      when /^-?-?help$/i,
           /^-?h$/i
        show_help :then_exit
      # ===================================================================== #
      # === easycompile --homedir
      # ===================================================================== #
      when /^-?-?home(_|-)?dir$/i
        use_the_home_directory_as_prefix
      # ===================================================================== #
      # === easycompile --OPEN_ITSELF
      # ===================================================================== #
      when /^-?-?OPEN(_|-)?ITSELF$/i,
           /^-?-?OPEN$i/ # OPEN_SELF
        open_this_file
        exit
      # ===================================================================== #
      # === ALL
      # ===================================================================== #
      when /^-?-?all$/i,
           /^-?-?everything$/i
        set_compile_these_programs Dir['*']
      # ===================================================================== #
      # === --remove-all-after-compile
      # ===================================================================== #
      when /^-?-?remove(_|-| )?all(_|-| )?after(_|-| )?compile$/i
        do_remove_all_after_compile
      # ===================================================================== #
      # === set_extract_to
      #
      # This entry allows us to define a custom temp-directory.
      #
      # Invocation example:
      #
      #   ecompile php* --extract-to=/Depot/opt/
      #
      # ===================================================================== #
      when /^-?-?set(_|-| )?extract(_|-| )?to=(.+)$/i, # $3
           /^-?-?extract(_|-| )?to=(.+)$/i  # $2
        _ = $2
        _ = $3.to_s.dup if $3
        set_extract_to(_) { :be_verbose }
      # ===================================================================== #
      # === ecompile --sco
      #
      # Invocation example:
      #
      #   ecompile --sco php*xz
      #
      # ===================================================================== #
      when /^-?-?sco$/i,
           /^-?-?extended-configure-options$/i,
           /^-?-?use-configure-options$/i
        @try_to_use_extended_configure_options = true
      # ===================================================================== #
      # === --wdeps
      # ===================================================================== #
      when /^-?-?wdeps$/i,
           /^-?-?with(_|-| )?deps$/i
        do_compile_with_dependencies
      # ===================================================================== #
      # === --skipmakeinstall
      # ===================================================================== #
      when /^-?-?SKIP_?MAKE_?INSTALL/i,
           'NO_MAKE_INSTALL',
           'NOMAKEINSTALL',
           'NOINSTALL',
           'SKIPINSTALL'
        enable_skip_make_install # Skip the "make install" step.
      # ===================================================================== #
      # === --dontcompile
      # ===================================================================== #
      when /^-?-?DONT(_|-| )?COMPILE$/i
        enable_dont_compile
      # ===================================================================== #
      # === --skip_extracting
      # ===================================================================== #
      when 'SKIP_EXTRACT',
           /^-?-?SKIP(_|-| )?EXTRACTING$/i,
           'SKIPEXTRACTING'
        skip_extracting
      # ===================================================================== #
      # === --appdir
      # ===================================================================== #
      when /^-?-?appdir$/i
        set_prefix :appdir
        opn; e 'Will compile as AppDir. The prefix now is '+simp(prefix?.to_s)
      else # else tag
        if File.exist?(i) or i.end_with?('.yml')
          add_this_archive(i)
        else
          # ================================================================= #
          # Next, we will attempt to find a valid entry. 
          # ================================================================= #
          i = attempt_to_find_a_valid_file(i)
          if i.respond_to?(:select)
            add_these_files(
              i.select {|file|
                File.exist? file.to_s
              }
            )
          end
        end
      end
    end
  end

end; end