#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'easycompile/base/process_the_input.rb'
# =========================================================================== #
module Easycompile

class Base

  # ========================================================================= #
  # === process_the_input
  # ========================================================================= #
  def process_the_input(
      i = compile_these_programs?
    )
    i.each {|this_entry|
      # ===================================================================== #
      # The this_entry part may look like so:
      #
      #   "php-7.4.2.tar.xz"
      #
      # ===================================================================== #
      # The entry may be nil at this point, though. In that case, we
      # fetch a random element.
      # ===================================================================== #
      this_entry = Dir['*'].first if this_entry.nil?
      this_entry = this_entry.to_s
      this_entry.sub!(/\^/,'') if this_entry.include? '^' # Remove ^ from the input here, if it is included.
      # ===================================================================== #
      # If input is a (positional) number, such as "3".
      # ===================================================================== #
      unless File.exist?(this_entry)
        if this_entry =~ /^\d+$/
          # ================================================================= #
          # Obtain all entries next.
          # ================================================================= #
          entries = Dir['*']
          unless entries.empty?
            this_entry = this_entry.to_i
            this_entry = entries.size if this_entry > entries.size # This is to fetch the proper last entry, if input is too long.
            this_entry = entries.sort[ (this_entry.to_i - 1) ] # Fetch an entry here.
          end
        end
      end
      # ===================================================================== #
      # === Handle .gem files too, early on - they won't need a build directory.
      # ===================================================================== #
      if this_entry =~ /\.gem$/ # If it is a gem file.
        do_not_create_a_build_directory # Gem files typically do not need a build dir.
      end
      # ===================================================================== #
      # === Handle yaml files first.
      #
      # If the input file is a yaml file, we will assume that the user wants
      # to change directory first into the SRC_DIR hierarchy.
      #
      # Invoke this by doing something like:
      # ===================================================================== #
      if this_entry.include? '.yml'
        yaml_dataset = get_dataset_from(this_entry)
        this_entry = yaml_dataset['program_path']
      end
      if File.directory? this_entry
        _ = Dir["#{this_entry}/*"].first # Fetch the first entry from this directory, in this case. But retain it only when it is an archive.
        if is_archive? _
          this_entry = _
        end # else we discard it.
      end
      # ===================================================================== #
      # Next, we need to check whether the input is an archive or whether
      # it is not. If it is a directory, then we will simply enter
      # this directory instead, without doing any further extraction.
      # ===================================================================== #
      unless this_entry.start_with?('--')
        if File.directory? this_entry # No need to do anything special in this case.
          # ================================================================= #
          # In this case we will enter the given directory at hand.
          # ================================================================= #
          cd this_entry
          consider_creating_a_build_directory
          run_configure_make_and_make_install
        else
          if File.exist?(this_entry)
            # ================================================================= #
            # Past this point we know that the entry must exist.
            # ================================================================= #
            set_original_input(this_entry)
            set_find_this_program(
              ProgramInformation.return_name(this_entry)
            )
            # =================================================================== #
            # The next method will also extract the archive, if the
            # archive exists and there is no other instruction given
            # by the user to NOT extract it.
            # =================================================================== #
            try_to_compile_or_install_this_program(this_entry)
            consider_symlinking_appdir if is_an_appdir?
            return_to_start_directory_again
            consider_removing_this_archive(this_entry)
          end
        end
      end
    }
  end

end; end