#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'easycompile/base/remove.rb'
# =========================================================================== #
module Easycompile

class Base

  # ========================================================================= #
  # === remove_directory
  #
  # This method will remove a directory (if the input argument is a
  # directory that is).
  # ========================================================================= #
  def remove_directory(i = nil)
    if i and File.directory?(i)
      i = i.dup if i.frozen?
      i.squeeze!('/')
      FileUtils.rm_rf(i) unless i == '/' # Don't delete "/" ever.
    end
  end; alias remove_this_directory remove_directory # === remove_this_directory

  # ========================================================================= #
  # === remove_this_archive
  #
  # This method can only be used to remove an archive, that is
  # some file like "foobar-1.2.0.tar.xz". It may never remove
  # a directory.
  # ========================================================================= #
  def remove_this_archive(i)
    if is_an_archive?(i)
      remove_file(i)
    end
  end

  # ========================================================================= #
  # === remove_extension_from
  # ========================================================================= #
  def remove_extension_from(i)
    i = i.dup # Work on a copy.
    i.sub!(/\.xz$/,'')    if i.end_with? '.xz'
    i.sub!(/\.gz$/,'')    if i.end_with? '.gz'
    i.sub!(/\.bzip2$/,'') if i.end_with? '.bzip2'
    i.sub!(/\.bzip$/,'')  if i.end_with? '.bzip'
    i.sub!(/\.tar$/,'')   if i.end_with? '.tar'
    i.sub!(/\.zip$/,'')   if i.end_with? '.zip'
    i
  end; alias remove_file_suffix        remove_extension_from # === remove_file_suffix
       alias remove_archive_at_the_end remove_extension_from # === remove_archive_at_the_end

  # ========================================================================= #
  # === remove_this_file
  # ========================================================================= #
  def remove_this_file(i)
    i = @start_dir+File.basename(i)
    opn_namespace; e 'Now deleting `'+sfile(i)+'`.'
    File.delete(i) if File.exist? i
  end; alias remove remove_this_file # === remove

  # ========================================================================= #
  # === do_remove_all_after_compile
  # ========================================================================= #
  def do_remove_all_after_compile
    opn_namespace; e 'We will remove all after compile.'
    @remove_all_after_compile = true
  end

  # ========================================================================= #
  # === remove_all_after_compile?
  # ========================================================================= #
  def remove_all_after_compile?
    @remove_all_after_compile
  end

end; end