#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'easycompile/base/reset.rb'
# =========================================================================== #
require 'easycompile/base/colours.rb'
require 'easycompile/constants/file_and_directory_constants.rb'

module Easycompile

class Base

  begin
    require 'rbt/misc/colourize_parser.rb'
  rescue LoadError; end
  # ========================================================================= #
  # === reset                                                     (reset tag)
  #
  # The instance variable we will use here:
  #
  #   @prefix_to_base_directory # This is used to denote what is the base
  # directory.
  #
  # ========================================================================= #
  def reset
    set_base_dir
    set_start_dir
    # ======================================================================= #
    # === @commandline_arguments
    #
    # This Array will hold all commandline arguments, e. g. ARGV.
    # ======================================================================= #
    @commandline_arguments = []
    # ======================================================================= #
    # === @compile_these_programs
    #
    # These are the programs, as an Array, that we wish to compile.
    # ======================================================================= #
    @compile_these_programs = []
    # ======================================================================= #
    # === @program_name
    # ======================================================================= #
    @program_name = nil
    # ======================================================================= #
    # === @compile_with_dependencies
    # ======================================================================= #
    @compile_with_dependencies = false # If true then we will first compile all dependencies.
    # ======================================================================= #
    # === @program_version
    # ======================================================================= #
    @program_version = '1.0.0' # Default.
    # ======================================================================= #
    # Designate the default extract-to directory next.
    # ======================================================================= #
    set_extract_to(:default)
    # ======================================================================= #
    # === @hash
    # ======================================================================= #
    @hash = {}
    # ======================================================================= #
    # === @skip_extracting
    # ======================================================================= #
    @skip_extracting = false # Whether to skip extracting or not.
    # ======================================================================= #
    # === @continue_after_extracting
    # ======================================================================= #
    @continue_after_extracting = true # if true we continue after extracting.
    # ======================================================================= #
    # === @build_directory_is_stored_here
    # ======================================================================= #
    @build_directory_is_stored_here = nil
    # ======================================================================= #
    # === @continue_past_configure_stage
    # ======================================================================= #
    @continue_past_configure_stage = true
    # ======================================================================= #
    # === @skip_make_install
    # ======================================================================= #
    @skip_make_install = false
    set_prefix # Default.
    # ======================================================================= #
    # === @prefix_to_base_directory
    # ======================================================================= #
    @prefix_to_base_directory = ''
    # ======================================================================= #
    # === @shall_we_create_a_build_directory
    #
    # This variable keeps track as to whether we will create a 
    # build directory or not.
    # ======================================================================= #
    @shall_we_create_a_build_directory = SHALL_WE_CREATE_A_BUILD_DIRECTORY
    # ======================================================================= #
    # === @prefix
    #
    # Which prefix is to be used. Defaults to /usr/.
    # ======================================================================= #
    @prefix = '/usr/'
    # ======================================================================= #
    # === @original_input
    # ======================================================================= #
    @original_input = nil
    # ======================================================================= #
    # === @temp_directory
    # ======================================================================= #
    @temp_directory = ::Easycompile.temp_directory?
    # ======================================================================= #
    # === @remove_all_after_compile
    # ======================================================================= #
    @remove_all_after_compile = false
    # ======================================================================= #
    # === @try_to_use_extended_configure_options
    #
    # If this variable is set to true then we will try to
    # return the extended configure options, which are
    # part of the RBT project.
    # ======================================================================= #
    @try_to_use_extended_configure_options = false
    # ======================================================================= #
    # === @colourize_parser
    # ======================================================================= #
    if cparser_is_available?
      @colourize_parser = RBT::ColourizeParser.new
    else
      @colourize_parser = nil
    end
    # ======================================================================= #
    # === @name_of_build_directory
    #
    # Choose a default name for the build directory. This can be
    # overruled if we have a .yml file that tells us to do so.
    # ======================================================================= #
    set_name_of_build_directory 'BUILD_DIRECTORY/'
    if File.exist? FILE_NAME_OF_THE_BUILD_DIRECTORY
      require 'yaml'
      set_name_of_build_directory(:load_the_yaml_file)
    end
  end

end; end