#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'easycompile/constants/file_and_directory_constants.rb'
# =========================================================================== #
require 'easycompile/project/project.rb'

module Easycompile

module Constants # === Easycompile::Constants

  # ========================================================================= #
  # === MESON_BUILD_FILE
  #
  # Refer to the name of the default meson-build file, which is
  # meson.build.
  # ========================================================================= #
  MESON_BUILD_FILE = 'meson.build'

  # ========================================================================= #
  # === CMAKE_FILE
  #
  # Refer to the name of the default cmake-file, which is called
  # CMakeLists.txt.
  # ========================================================================= #
  CMAKE_FILE = 'CMakeLists.txt'

  # ========================================================================= #
  # === FILE_NAME_OF_THE_BUILD_DIRECTORY
  # ========================================================================= #
  FILE_NAME_OF_THE_BUILD_DIRECTORY =
    "#{PROJECT_BASE_DIRECTORY}yaml/name_of_the_build_directory.yml"

  # ========================================================================= #
  # === LAST_DOWNLOADED_FILE
  # ========================================================================= #
  LAST_DOWNLOADED_FILE = "#{ENV['HOME']}/LAST_DOWNLOADED_FILE.md"

  # ========================================================================= #
  # === INDIVIDUAL_COOKBOOKS
  #
  # This will currently use a hardcoded path, which is only useful on
  # my home setup..
  # ========================================================================= #
  INDIVIDUAL_COOKBOOKS =
    '/home/x/DATA/PROGRAMMING_LANGUAGES/RUBY/src/'\
    'rbt/lib/rbt/yaml/cookbooks/'

  # ========================================================================= #
  # === RUBY_SRC
  #
  # This constant is guaranteed to have the last character a '/'. It is
  # only useful on my home setup, though - other users won't need this
  # constant.
  # ========================================================================= #
  if ENV['RUBY_SRC']
    RUBY_SRC = ENV['RUBY_SRC'].to_s+'/'
  else
    RUBY_SRC = '/home/x/DATA/PROGRAMMING_LANGUAGES/RUBY/src/'
  end

  # ========================================================================= #
  # === ruby_src?
  # ========================================================================= #
  def ruby_src?
    RUBY_SRC
  end

  # ========================================================================= #
  # === LOCATION_OF_SETUP_RB
  #
  # We can simply make use of the RUBY_SRC constant here.
  # ========================================================================= #
  LOCATION_OF_SETUP_RB =
    "#{RUBY_SRC}roebe/lib/roebe/setup/setup.rb"

  # ========================================================================= #
  # === SRC_DIR
  #
  # This constant is guaranteed to have the last character a '/'.
  # ========================================================================= #
  if ENV['SRC_DIR']
    SRC_DIR = ENV['SRC_DIR'].to_s+'/'
  else
    SRC_DIR = '/home/x/src/'
  end

  # ========================================================================= #
  # === source_dir?
  # ========================================================================= #
  def source_dir?
    SRC_DIR
  end; alias src_dir? source_dir? # === src_dir?

  # ========================================================================= #
  # === TEMP_DIR
  # ========================================================================= #
  if ENV['MY_TEMP']
    TEMP_DIR = ENV['MY_TEMP'].to_s.dup+'/'
  elsif Dir.exist? '/home/Temp'
    TEMP_DIR = '/home/Temp/'
  else
    TEMP_DIR = '/tmp/'
  end

  # ========================================================================= #
  # === temp_dir?
  # ========================================================================= #
  def self.temp_dir?
    TEMP_DIR
  end; self.instance_eval { alias temp_directory? temp_dir? } # === Easycompile::Constants.temp_directory?

end

# =========================================================================== #
# === Easycompile.temp_dir?
# =========================================================================== #
def self.temp_dir?
  Constants::TEMP_DIR
end; self.instance_eval { alias temp_directory? temp_dir? } # === Easycompile.temp_directory?

# =========================================================================== #
# === Easycompile.source_dir?
# =========================================================================== #
def self.source_dir?
  Constants::SRC_DIR
end; self.instance_eval { alias src_dir? source_dir? } # === Easycompile.src_dir?

# =========================================================================== #
# === Easycompile.ruby_src_dir?
# =========================================================================== #
def self.ruby_src_dir?
  Constants::RUBY_SRC
end; self.instance_eval { alias ruby_src? ruby_src_dir? } # === Easycompile.ruby_src?

end