#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# === Easycompile::Easycompile
#
# This will extract an archive, then compile into the given prefix,
# which defaults to /usr/ for this class.
# =========================================================================== #
require 'easycompile/base/easycompile.rb'

module Easycompile # === Easycompile::Easycompile

class Easycompile < Base

  # ========================================================================= #
  # === initialize
  #
  # We can use more advanced compile instructions such as:
  #
  #   Easycompile::Easycompile.new(i, extract_to: EXTRACT_TO)
  #
  # The first argument is the name of the program in question.
  # ========================================================================= #
  def initialize(
      i           = nil,
      run_already = true,
      &block
    )
    set_prefix '/usr' # This is the default prefix anyway.
    super(i, :dont_run_yet)
    if run_already.is_a? Hash
      set_hash(run_already) # Here the prefix can be overruled.
      run_already = true
    end
    if i.is_a? Array
      i = i.first
    end
    if i.end_with? '.yml'
      i = return_yaml_file(i)
      set_original_input(i)
    end
    # ======================================================================= #
    # === Handle blocks next
    # ======================================================================= #
    if block_given?
      yielded = yield
      # ===================================================================== #
      # === Handle Hashes next
      # ===================================================================== #
      if yielded.is_a? Hash
        # =================================================================== #
        # === { :prefix => :appdir }
        #
        # This is the default entry point for programs that are compiled
        # via an AppDir prefix.
        # =================================================================== #
        if yielded.has_key? :prefix
          set_prefix(
            yielded[:prefix]
          )
        end
      end
    end
    set_original_input(i)
    run if run_already # Call the parent method.
  end

  # ========================================================================= #
  # === Easycompile[]
  # ========================================================================= #
  def self.[](i)
    new(i)
  end

end; end

if __FILE__ == $PROGRAM_NAME
  puts Easycompile::Easycompile.new(ARGV)
end # ecompile