#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# Here we collect methods which are directly available on the module
# level of the project.
# =========================================================================== #
# require 'easycompile/toplevel_methods/misc.rb'
# =========================================================================== #
module Easycompile

  require 'easycompile/constants/constants.rb'
  # ========================================================================= #
  # We wish to include these constants onto the toplevel module next.
  # ========================================================================= #
  include Easycompile::Constants

  require 'easycompile/easycompile/easycompile.rb'
  require 'easycompile/compile_as_appdir/compile_as_appdir.rb'
  # ========================================================================= #
  # === Easycompile.compile
  #
  # This method must be able to tap into CompileAsAppdir, as well
  # as invoke Easycompile, so both .rb files are required here.
  #
  # If no input is given then a random entry will be fetched.
  #
  # Invocation example:
  #
  #   Easycompile.compile('wv.yml', :appdir)
  #
  # ========================================================================= #
  def self.compile(
      i = nil, optional_compile_as_appdir = false
    )
    if i.nil?
      i = try_to_randomly_fetch_an_archive_from_the_current_directory
    end
    case optional_compile_as_appdir
    when :appdir
      # ===================================================================== #
      # Make it more explicit in this case.
      # ===================================================================== #
      optional_compile_as_appdir = true
    end
    if optional_compile_as_appdir
      ::Easycompile::CompileAsAppdir[i]
    else
      ::Easycompile::Easycompile.new(i)
    end
  end; self.instance_eval { alias easycompile compile } # === Easycompile.easycompile
       self.instance_eval { alias []          compile } # === Easycompile[]

end